@@ -20,7 +20,7 @@
  *
  *
  * nessus-fetch is a simple utility to retrieve Nessus plugins from nessus.org
- * $Id: nessus-fetch.c,v 1.1.2.20 2005/11/22 16:32:55 renaud Exp $
+ * $Id: nessus-fetch.c,v 1.1.2.21 2006/04/20 13:52:47 renaud Exp $
  */
 #include <includes.h>
 
@@ -972,7 +972,7 @@ void check_subscription()
 	}
   if (strstr(result, SUCCESS_MSG) != NULL )
   {
-   fprintf(stderr, "nessus-fetch is properly configured to receive a direct plugin feed\n");
+   fprintf(stderr, "nessus-fetch is properly configured to receive a plugin feed\n");
    exit(0);
   }
   else if ( strstr(result, ERROR_PREFIX ) != NULL )
@@ -983,7 +983,7 @@ void check_subscription()
   }
  }
  else {
-   fprintf(stderr, "nessus-fetch is not configured to receive a direct plugin feed\n");
+   fprintf(stderr, "nessus-fetch is not configured to receive a plugin feed\n");
    exit(1);
    }
  
