@@ -473,10 +473,7 @@ backend_close(be)
 #ifdef HAVE_MMAP
  if(backends[be].mmap)
  {
-  struct stat  buf;
-  int len;
-  fstat(backends[be].fd, &buf);
-  len = (int)buf.st_size;
+  int len = backends[be].mmap_size;
   munmap(backends[be].mmap, len);
   backends[be].mmap = NULL;
   efree(&backends[be].lines);
