@@ -587,16 +587,7 @@ cli_send_prefs_arglist(pref, upload, pprefs)
      	harg_add_int(*upload, pref->value, 1);
    	}
 	
- 	if ( pprefs == 0 )	network_printf("%s <|> %s\n", pref->name, pref->value);
-	else if ( strchr(pref->value, ';') != NULL )
-	{
-	 char * p;
-	 p = strchr(pref->value, ';');
-	 p[0] = '\0';
-	 network_printf("%s <|> %s\n", pref->name, pref->value);
-	 p[0] = ';';
-	}
-        else network_printf("%s <|> %s\n", pref->name, pref->value);
+        network_printf("%s <|> %s\n", pref->name, pref->value);
     }
    else if(pref->type == ARG_INT)
     {
