@@ -14,6 +14,17 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ * In addition, as a special exception, Renaud Deraison
+ * gives permission to link the code of this program with any
+ * version of the OpenSSL library which is distributed under a
+ * license identical to that listed in the included COPYING.OpenSSL
+ * file, and distribute linked combinations including the two.
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * this file, you may extend this exception to your version of the
+ * file, but you are not obligated to do so.  If you do not wish to
+ * do so, delete this exception statement from your version.
  */
  
 #ifndef _NESSUSC_COMM_H
@@ -21,10 +32,13 @@
 
 
 int comm_init(int,char*);
-int comm_get_pluginlist(void);
+int comm_get_pluginlist();
 int comm_get_preferences(struct arglist *);
+int cli_comm_get_preferences(struct arglist *);
 int comm_get_rules(struct arglist *);
 
+int comm_get_plugins();
+
 int comm_send_preferences(struct arglist *);
 int comm_send_long_preferences(struct arglist*);
 int comm_send_rules(struct arglist *);
@@ -37,6 +51,10 @@ void comm_delete_session(char*);
 void comm_restore_session(char*);
 void comm_stop_detached_session( char *name);
 
+int comm_plugin_upload(char*);
+
+int comm_get_dependencies();
+
 #ifdef ENABLE_SAVE_TESTS
 harglst * comm_get_detached_sessions(void);
 #endif
