@@ -111,6 +111,12 @@ idle_socket(struct arglist * ctrls)
       fprintf(stderr, "idle_socket: GlobalSocket=%d\n", GlobalSocket);
       return FALSE;
     }
+
+  if ( stream_pending(GlobalSocket) > 0 )
+  {
+    monitor_input_callback(ctrls, soc /* ? Not used */, 0);
+    return TRUE;
+  }
   soc = nessus_get_socket_from_connection(GlobalSocket);
   if((soc < 0) || (soc >= FD_SETSIZE))
   {
@@ -289,9 +295,9 @@ monitor_list_update(ctrls,msg, short_status)
     
    gmax = max;
    gcurrent = atoi(current);
-   f = (gcurrent/gmax);
-   if(f>=1.0)f=1.0;
-   if(f<=0.0)f=0.0;
+   f = (gfloat)(gcurrent/gmax);
+   if(f >= 1.0)f = 0.99;
+   else if(f <= 0)f = 0;
    gtk_progress_bar_update (GTK_PROGRESS_BAR(progress_bar), f);
 
    flag = 1;
