@@ -14,6 +14,17 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ * In addition, as a special exception, Renaud Deraison
+ * gives permission to link the code of this program with any
+ * version of the OpenSSL library which is distributed under a
+ * license identical to that listed in the included COPYING.OpenSSL
+ * file, and distribute linked combinations including the two.
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * this file, you may extend this exception to your version of the
+ * file, but you are not obligated to do so.  If you do not wish to
+ * do so, delete this exception statement from your version.
  */
 
 #ifndef _NESSUSC_PREFERENCES_H
@@ -27,6 +38,9 @@ void   pluginset_reload(struct arglist *, struct arglist *);
 void   prefs_check_defaults(struct arglist *);
 int    preferences_process(char *, struct arglist *);
 int    preferences_generate_new_file();
+char * plugin_asc_id(struct arglist*);
+char * preferences_get_filename();
+char * preferences_get_altname(const char*);
 
 #ifdef _WIN32
 /* applies to some windows misunderstanding */
