@@ -19,19 +19,18 @@
 #ifndef _NESSUSC_PREFS_HELP_H
 #define _NESSUSC_PREFS_HELP_H
 
-#ifdef ENABLE_CRYPTO_LAYER
-#define HLP_AUTH_SERVER "Enter the server name, where the Nessusd server resides on. \
-This may be a domain name or an IP address. If you connect to that server for the \
-first time, you will be noticed when a cryptographic server key is stored in your \
-key data base.  IT WILL BE UP TO YOU to quit immediately afterwards and check/remove \
-that key from the data base if (use options -L and -K) if you do not trust that \
-particular Nessusd server."
-#else
 #define HLP_AUTH_SERVER "Enter the server name, where the Nessusd server resides on. \
 This may be a domain name or an IP address."
+#ifdef DEFAULT_PORT
+#define HLP_AUTH_PORT \
+"Enter the port number where you will be serviced by\
+ the Nessud server. With older server systems, this is\
+ the port 3001, but the official port is 1241."
+#else
+#define HLP_AUTH_PORT \
+"Enter the port number where you will be serviced by\
+ the Nessud server."
 #endif
-#define HLP_AUTH_PORT "Enter the port number where you will be serviced by the Nessud \
-server."
 #ifdef USE_ZLIB_COMPRESSION
 #define HLP_CIPHER_CHOICE "Enter the channel encrytion <cipher>/<hash>:<compression>. \
 A good choice for <cipher> is BLOWFISH, or TWOFISH an a good choice for <hash> is \
@@ -47,8 +46,13 @@ a good choice for <hash> is ripemd160."
 Nessusd server. If you log in for the first time, you will be asked for a password. \
 Maybe you need to ask your Nessusd administrator to create a login for you."
 
-#define HLP_MISC_MAX_THREADS "Maximal of number of threads that the server will create \
-for this test"
+#define HLP_MISC_MAX_HOSTS "Maximal of number of hosts that the server will test at \
+the same time. Be aware that the remote host will spawn max_hosts x max_checks \
+processes !"
+
+#define HLP_MISC_MAX_CHECKS "Maximal number of security checks that will be launched at \
+the same time against each host. Be aware that the remote host will spawn \
+max_hosts x max_checks processes !"
 
 #define HLP_TEST_FILE "Name of the remote file that several plugins will attempt \
 to read"
@@ -70,18 +74,37 @@ configured (this option is still experimental)"
 #define HLP_SCAN_OPT_OPTIMIZE "Security tests may ask the server to be \
 launched if and only if some information gathered by other \
 test exist in the knowledge base, or if and only if a given \
-port is open. It is possible (although it has *not* been found in \
-practice so far) that these optimizations make some tests \
-miss a given vulnerability. If you are very paranoid \
-you may want to turn this option off."
+port is open. This option speeds up the test, but may \
+make Nessus miss some vulnerability. If you are paranoid, \
+disable this option"
 
-#define HLP_SCAN_OPT_SCAN_LEVEL_NORMAL "Not implemented"
-#define HLP_SCAN_OPT_SCAN_LEVEL_HEAVY "Not implemented"
+#define HLP_SCAN_OPT_SAFE_CHECKS "\
+Some security checks may harm the remote server, by \
+disabling the remote service temporarily or until \
+a reboot. If you enable this option, Nessus will \
+rely on banners instead of actually performing \
+a security check. You will obtain a less reliable \
+report, but you will less likely disrupt the network users \
+by doing a test. From a security point of view, we \
+recommand you disable this option. From a sysadmin \
+point of view, we recommand you enable it"
+
+
+#define HLP_SCAN_OPT_USE_MAC_ADDR "\
+If you enable this option, the hosts on the local network \
+will be designated by their ethernet MAC address instead of \
+their IP address. This is especially useful if you are using \
+Nessus in a DHCP network. If unsure, disable this option"
 
 #define HLP_SCAN_OPT_PORT_RANGE "Ports that will be scanned by Nessus. You can enter \
-single ports, such as \"1-8000\" or more complex sets, such as\"21,23,25,1024-2048,6000\" \
-Put \"-1\" for no portscan"
+single ports, such as \"1-8000\"; or more complex sets, such as \"21,23,25,1024-2048,6000\". \
+Put \"-1\" for no portscan, or put \"default\" to scan default ports in the Nessus services file."
 
+#define HLP_UNSCANNED_CLOSED "To save scanning time, you may ask Nessus to declare \
+TCP ports it did not scan as closed. This will result in an incomplete audit \
+but it will reduce scanning time and prevent nessusd from sending packets \
+to ports you did not specify. \
+If this option is disabled, then Nessus will consider ports whose state it does not know as open"
 
 #define HLP_HOST_EXPANSION_DNS "Nessus will perform an AXFR request \
 (that is, a zone transfer) to the remote name server and will attempt to obtain \
@@ -95,28 +118,14 @@ Beware : this test is recursive"
 of the remote host. If you select this option, you should allow Nessus to \
 ping the hosts before scanning them in the 'Scan options' section"
 
-#define HLP_HOST_EXPANSION_MAX_HOSTS "Maximal number of hosts to test. Set this \
-to -1 if you do not want any limit"
 
 #define HLP_TARGET_PRIMARY_TARGET "The first host(s) that will be attacked by Nessus. \
 The options below allow you to extend the test to a larger set of computer. You may \
 define several primary targets by separating them with a comma (,). ie : \"host1,host2\""
-
-#define HLP_TARGET_SUBNET_CLASS_A "Set this if your subnet is a class A subnet (ie: your\
- netmask is something like 'x.255.255.255')"
- 
-#define HLP_TARGET_SUBNET_CLASS_B "Set this if your subnet is a class B subnet (ie: your\
- netmask is something like 'x.x.255.255')"
-
-#define HLP_TARGET_SUBNET_CLASS_C "Set this if your subnet is a class C subnet (ie: your\
- netmask is something like 'x.x.x.255')"
-
-#define HLP_USER_EMAIL "Set this to your email address. Some security checks will attempt\
- to send some files gathered on the victims"
  
 #define HLP_CGI_PATH "It is possible to check for the presence of CGIs in multiple paths\
  like /cgi-bin, /cgis, /home-cgis, and so on. In that case, put all your paths here\
- separated by a comma. For instance:   '/cgi-bin:/cgi-aws:/~deraison/cgi'"
+ separated by colons. For instance:   '/cgi-bin:/cgi-aws:/~deraison/cgi'"
 
 #define HLP_WARNING "The warning sign means that this plugin may harm the \n\
 remote host by disabling the attacked service or by crashing the host. \n\
@@ -170,7 +179,15 @@ will not be launched again"
 of a knowledge base."
 
 
-#endif
-
+#define HLP_DIFF_SCAN "If this option is set, the client will only report \
+what has changed between the new scan and the last one"
 
 #endif
+
+#define HLP_ENABLE_DEPS_AT_RUNTIME "If you enable this option, then nessusd \
+will enable the plugins that are depended on by the set of plugins you \
+selected. "
+#define HLP_SILENT_DEPS "If you enable this option, then nessusd \
+will not report data coming from the plugins that you did not specifically \
+enable. "
+#endif
