@@ -4,7 +4,7 @@
 #ifdef ENABLE_SAVE_KB
 int  detached_setup_mail_file(struct arglist*, char*);
 void detached_copy_data(struct arglist*, char*, int);
-void detached_send_mail(struct arglist*);
+void detached_send_email(struct arglist*);
 
 
 int detached_new_session(struct arglist *, char *);
