@@ -76,8 +76,8 @@ int preferences_new(char * name)
 
  fprintf(fd, "# Log file : \n");
  fprintf(fd, "logfile = %s\n\n", NESSUSD_MESSAGES);
- fprintf(fd, "# Shall we log every details of the attack ?\n");
- fprintf(fd, "log_whole_attack = yes\n\n");
+ fprintf(fd, "# Shall we log every details of the attack ? (disk intensive)\n");
+ fprintf(fd, "log_whole_attack = no\n\n");
  fprintf(fd, "# Log the name of the plugins that are loaded by the server ?\n");
  fprintf(fd, "log_plugins_name_at_load = no\n\n");
  fprintf(fd, "# Dump file for debugging output, use `-' for stdout\n");
